@@ -494,7 +494,7 @@ void display_play(struct level* plevel, struct level* plevelreplay)
                             c = font_logo_colours[x] - '0';
                         else
                         {
-                            printw(buffer + x);
+                            printw("%s", buffer + x);
                             x = strlen(buffer);
                             break;
                         }
@@ -1631,7 +1631,7 @@ void display_options_load()
     options_debug = 0;
 
     getfilename("colours", filename, 0, 1);
-    sprintf(options_colours, "%s/%s", filename, COLOURS_DEFAULT);
+    snprintf(options_colours, sizeof(options_colours), "%s/%s", filename, COLOURS_DEFAULT);
 
     getfilename("curses.chroma", filename, 0, 0);
 
