@@ -132,7 +132,7 @@ void menu_displayentry(struct menu *pmenu, struct menuentry *pentry, int y, int
         {   
             utf8strncpy(buffer, pentry->text2, menu_width - 2);
             x = menu_offset + menu_width - 1 - utf8strlen(buffer);
-            mvprintw(y, x, buffer);
+            mvprintw(y, x, "%s", buffer);
         }
 
         /* Plot main text */
@@ -148,7 +148,7 @@ void menu_displayentry(struct menu *pmenu, struct menuentry *pentry, int y, int
 
             if(pentry->flags & MENU_BOLD)
                 attron(A_BOLD);
-            mvprintw(y, x, buffer);
+            mvprintw(y, x, "%s", buffer);
             if(pentry->flags & MENU_BOLD)
                 attroff(A_BOLD);
         }
@@ -197,7 +197,7 @@ void menu_displayentry(struct menu *pmenu, struct menuentry *pentry, int y, int
             x = menu_offset + menu_width - 1 - utf8strlen(buffer);
             if(pentry->flags & MENU_EDITING)
                 attron(COLOR_PAIR(colourpair_white));
-            mvprintw(y, x, buffer);
+            mvprintw(y, x, "%s", buffer);
             if(pentry->flags & MENU_EDITING)
                 attroff(COLOR_PAIR(colourpair_white));
         }
@@ -208,7 +208,7 @@ void menu_displayentry(struct menu *pmenu, struct menuentry *pentry, int y, int
             utf8strncpy(buffer, pentry->text3, menu_width - 2);
 
             x = menu_offset + 1;
-            mvprintw(y, x, buffer);
+            mvprintw(y, x, "%s", buffer);
         }
 
         if(selected)
@@ -357,7 +357,7 @@ void menu_display(struct menu *pmenu, int redraw)
                 if(i == 5) attron(COLOR_PAIR(colourpair_magenta));
 
                 sprintf(buffer, "%c", title[i]);
-                mvprintw(2, x, buffer);
+                mvprintw(2, x, "%s", buffer);
                 x +=2;
             }
             attroff(COLOR_PAIR(colourpair_red));
@@ -373,7 +373,7 @@ void menu_display(struct menu *pmenu, int redraw)
             if(x < 0)
             {
                 x = (display_size_x - utf8strlen(pmenu->title)) / 2;
-                mvprintw(y, x, pmenu->title);
+                mvprintw(y, x, "%s", pmenu->title);
             }
             else
             {
@@ -387,7 +387,7 @@ void menu_display(struct menu *pmenu, int redraw)
             buffer[j] = pmenu->title[i + j]; j ++;
             }
             buffer[j] = 0;
-                    mvprintw(y, x, buffer);
+                    mvprintw(y, x, "%s", buffer);
             x += 2;  i += j - 1;
                 }
             }
